===============
Django Frontend
===============

.. image:: https://travis-ci.org/jonfaustman/django-frontend.png?branch=master
    :target: https://travis-ci.org/jonfaustman/django-frontend

Django Frontend is a collection of static files and templates to jumpstart Django front-end development.

With the convenience of an installable Django application, easily add some of the most widely used static files and create custom templates built on top of one of the most well-known, widespread templates (`HTML5 Boilerplate <https://github.com/h5bp/html5-boilerplate>`_ .)

:Package: `https://pypi.python.org/pypi/django-frontend <https://pypi.python.org/pypi/django-frontend>`_
:Source: `https://github.com/jonfaustman/django-frontend <https://github.com/jonfaustman/django-frontend>`_

---------
Starring
---------
* `HTML5 Boilerplate (based on 4.3.0/master) <https://github.com/h5bp/html5-boilerplate>`_
* `Modernizr (2.8.2) <https://github.com/Modernizr/Modernizr>`_
* `normalize.css (3.0.1) <https://github.com/necolas/normalize.css>`_
* `jQuery (1.11.1) and (2.1.1) <https://github.com/jquery/jquery>`_
* `jQuery UI (1.11.0) <https://github.com/jquery/jquery-ui>`_
* `jQuery DataTables (1.10.0) <https://github.com/DataTables/DataTables>`_
* `jQuery Dynamic Formset (1.2) <https://github.com/elo80ka/django-dynamic-formset>`_
* `jQuery ScrollTo (1.4.12) <https://github.com/flesler/jquery.scrollTo>`_
* `jQuery Smooth Scroll (1.4.13) <https://github.com/kswedberg/jquery-smooth-scroll>`_
* `Twitter Bootstrap (3.2.0) <https://github.com/twbs/bootstrap>`_
* `iOS-Orientationchange-Fix <https://github.com/scottjehl/iOS-Orientationchange-Fix>`_
* `Font Awesome (4.1.0) <https://github.com/FortAwesome/Font-Awesome>`_

-----------------
More Information
-----------------

For more information, instructions on how to get started, a changelog and a roadmap `read the documentation <https://django-frontend.readthedocs.org/>`_.
